==> jaxb2-rich-contract-plugin-2.1.0-sources.jar: com/kscs/util/jaxb/_interface/ObjectFactory.java <==
//
// Diese Datei wurde mit der JavaTM Architecture for XML Binding(JAXB) Reference Implementation, v2.2.11 generiert 
// Siehe <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren. 
// Generiert: 2020.12.15 um 09:23:54 AM CET 
//


package com.kscs.util.jaxb._interface;

import javax.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the com.kscs.util.jaxb._interface package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: com.kscs.util.jaxb._interface
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link Interfaces }
     * 
     */
    public Interfaces createInterfaces() {
        return new Interfaces();
    }

    /**
     * Create an instance of {@link Interface }
     * 
     */
    public Interface createInterface() {
        return new Interface();
    }

    /**
     * Create an instance of {@link SchemaComponent }
     * 
     */
    public SchemaComponent createSchemaComponent() {
        return new SchemaComponent();
    }

}

==> jaxb2-rich-contract-plugin-4.1.0-sources.jar: com/kscs/util/jaxb/_interface/ObjectFactory.java <==
//
// Diese Datei wurde mit der Eclipse Implementation of JAXB, v4.0.2 generiert 
// Siehe https://eclipse-ee4j.github.io/jaxb-ri 
// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren. 
//


package com.kscs.util.jaxb._interface;

import jakarta.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the com.kscs.util.jaxb._interface package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: com.kscs.util.jaxb._interface
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link Interfaces }
     * 
     * @return
     *     the new instance of {@link Interfaces }
     */
    public Interfaces createInterfaces() {
        return new Interfaces();
    }

    /**
     * Create an instance of {@link Interface }
     * 
     * @return
     *     the new instance of {@link Interface }
     */
    public Interface createInterface() {
        return new Interface();
    }

    /**
     * Create an instance of {@link SchemaComponent }
     * 
     * @return
     *     the new instance of {@link SchemaComponent }
     */
    public SchemaComponent createSchemaComponent() {
        return new SchemaComponent();
    }

}
